@@ -2,7 +2,7 @@ import kubernetes
 
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
 from ocp_resources.resource import NamespacedResource
-from ocp_resources.utils import TimeoutSampler
+from timeout_sampler import TimeoutSampler
 
 
 class DaemonSet(NamespacedResource):
